# YCML

This package contains a collection of code that I've written over the past years for pretty run-of-the-mill deployments of machine learning projects.

Documentation is sparse because this is mostly for my own personal use. Sorry!

See [helloworld](helloworld) for a sample ML project template.

## Usage

To use it in your files, add

    git+https://github.com/skylander86/ycml.git@v0.1.5#egg=ycml

to your `requirements.txt`.

## Development Tips

In your app, do
```
pip install -e ../ycml
```
to install module in "editable" mode.
